
	interface
	subroutine pder(h,f,dx,nx,nz,dim,dir,nop)
	real h(nx,nz)
	real f(nx,nz)
!hpf$	distribute f*(*,block)
!hpf$   align h with *f
        parameter(maxnop=8)
        real g(maxnop)
        integer dir,dim
        real dx
	end subroutine pder
	end interface

	interface 

	subroutine inter(h,f,nx,nz,dim,dir)
	real h(nx,nz)
	real f(nx,nz)
!hpf$	distribute f*(*,block)
!hpf$   align h with *f
	integer dir,dim
	real dx
	end subroutine inter
	end interface

