

! Global mapping specification

	module mapping

c	parameter(nx=4000,nz=600)
c	parameter(nx=2500,nz=1000)
c 	parameter(nx=1750,nz=750)
c	parameter(nx=1250,nz=500)
c	parameter(nx=500,nz=500)
	parameter(nx=500,nz=250)
	parameter(maxnt=30000)
	parameter(maxnr=100)
	parameter(pi=3.14159265358)

!hpf$	template, dimension (nx,nz) 	:: tt
!hpf$	distribute (*,block) :: tt

	end module mapping


