c ---------

	subroutine time_check(i,nt)

	include '/usr/include/cm/timer-fort.h'

	call cm_timer_stop(0)
	busy=cm_timer_read_cm_busy(0)
	write(*,*)' Busy sofar : ',busy/60.,' min.'
	elapsed=cm_timer_read_elapsed(0)
	write(*,*)' Elapsed sofar : ',elapsed/60.,' min.'
	write(*,*)' Pred. total CM-busy time : ',busy/i*nt/60,' min.'
	write(*,*)' Pred. total CM-elapsed time : ',elapsed/i*nt/60,' min.'
	call cm_timer_start(0)

	return
	end

