c
c
c
c PSV wave propagation in spherical coordinates
c --------------------------------------------
c
c
c
c                                        Heiner Igel, 1994
c

	program main

	include 'common.h'

c timing specs

        real*4 dtime,delta,tarray(2)
        external dtime

c input

	call psv_input

c initialization

	call psv_init


c check

	call psv_check


c time evolution

	it1=1
	it2=2
	it3=2

c timing

	t0=secnds(0.0)

	do it=1,nt

	it2=it1
	it1=it3


	if(aa==1000.)then
	 if(it.ge.it0)then
		call psv_evolution
	  endif
	else
	  call psv_evolution
	endif
	
	call psv_output

	it3=it2

c timing

	if(aa.ne.1000.)then
	if(mod(it,icheck)==0)then
        call time_check(it,nt,icheck,t0)
	endif
	else
	if(it.gt.it0)then
	if(mod(it,icheck)==0)then
        call time_check(it,nt,icheck,t0)
	endif
	endif
	endif


	enddo

	end program main




