
! Global mapping specification


c	parameter(nx=4000,nz=750)
c	parameter(nx=2500,nz=750)
 	parameter(nx=1750,nz=750)
c	parameter(nx=1250,nz=500)
c	parameter(nx=1000,nz=1000)
c	parameter(nx=500,nz=500)
c	parameter(nx=500,nz=250)
	parameter(maxnt=10000)
	parameter(maxnr=50)
	parameter(pi=3.14159265358)

c space variables

	real, dimension (nx,nz) :: mu,lam,rho,window,gauss
	real, dimension (nx,nz) :: r1,r2,theta1,theta2
	real, dimension (nx,nz) :: r1inv,r2inv,rhoinv,cot1,cot2
	real, dimension (nx,nz) :: u11,u12,u21,u22
	real, dimension (nx,nz) :: s1,s2,s3,s4
	real, dimension (nx,nz) :: exz,ezz,exx
	real, dimension (nx,nz) :: s1o,s2o,s3o,s4o

	real vmu(nz)
	real vlam(nz)
	real vr1(nz)
	real vr2(nz)
	real vtheta1(nx)
	real vtheta2(nx)
	real vrho(nz)
	real rho0,vs0
	real rec_loc(maxnr)

c source 

	parameter(nbuf=200)
	real seis(2,maxnt*maxnr)
	real seisxz(maxnt*maxnr)
	real seiszz(maxnt*maxnr)
	real seisxx(maxnt*maxnr)
	real so(2,maxnt*8)
	integer isx,isz,source_type
	integer xid
	real alpha

c FD

	integer nabsorb,iord
	real dr,dphi,dt
	integer izfree

c layout

	character*80 seisfile,snapfile,recfile



	common /creal/ dr,dphi,dt,vlam,vmu,u,vr1,vr2,vtheta1,vrho,so,
     &                 Rmax,vtheta2,aa,interp,deriv,alpha,gauss,absorb,
     &		       aabsorb,vp0,vs0,rho0,dmax,snaps,mask,lam,mu,rho,
     &                 r1,r2,theta1,theta2,seis,rec_loc,sdepth,
     &                 r1inv,r2inv,cot1,cot2,rhoinv,window,
     &                 u11,u12,u21,u22,seisxz,seiszz,seisxx,t0,
     &                 s1,s2,s3,s4,s1o,s2o,s3o,s4o,exz,ezz,exx

	common /cint/ nt,it,isx,isz,it1,it2,it3,isnap,icolor,xid,icheckpoint,
     &                ixa,ixe,irec,idisp,isamp,izrec,it0,ifork,izfree,nr,
     &	              nabsorb,iord,model_type,icheck,nop,icomp,source_type


	common /cchar/ seisfile,snapfile,recfile
