c ---------

        subroutine time_check(i,nt,icheck,t0)

        diff=secnds(t0)

        write(*,*)' Pred. total: ',diff/icheck*nt/60,'min.
     &   (',diff/icheck*nt/3600,'hrs) -> ',100*real(i)/real(nt),'% done '

	t0=secnds(0.0)

        return
        end
